@@ -4,6 +4,8 @@
 
 #include "playerutils.h"
 
+ #include <QAudio>
+
 PlayerUtils::PlayerUtils(QObject *parent) : QObject(parent)
 {
 
@@ -13,3 +15,8 @@ QString PlayerUtils::formatTimestamp(quint64 stamp)
 {
     return m_format.formatDuration(stamp, KFormat::FoldHours);
 }
+
+float PlayerUtils::convertVolume(float volume)
+{
+    return QAudio::convertVolume(volume, QAudio::LogarithmicVolumeScale, QAudio::LinearVolumeScale);
+}
